Mode

Enum Mode 

pub enum Mode {
    Classic,
    Fd {
        allow_bit_rate_switching: bool,
        data_phase_timing: BitTiming,
    },
}
Enable/disable CAN-FD and related features

Variants



Classic

Classic mode with 8-bytes data. Reception of an FD frame is considered an error.



Fd

Transmission and reception of CAN FD frames (with up to 64 bytes of data) is enabled. This does not prevent use of classic CAN frames.

Fields

allow_bit_rate_switching: bool

If true, FD frames can be transmitted with bit rate switching. Otherwise, attempts to transmit FD frames will return errors.

Regardless of this setting, data phase timing still must be configured as reception of bit-rate-switched messages is still possible.

data_phase_timing: BitTiming

Bit timing parameters for the data phase of bit rate switched FD frames.