RxFifoMode

Struct RxFifoMode 

pub struct RxFifoMode(/* private fields */);
Mode of operation for the RX FIFO

Implementations

Source

impl RxFifoMode

pub fn blocking() -> Self

Blocking mode

When the RX FIFO is full, incoming messages are dropped until at least one message has been read out from the FIFO.

pub unsafe fn overwrite() -> Self

Overwriting mode

When the RX FIFO is full, the oldest messsage will be deleted and a new message will take its place.

Safety

For the RX FIFO running in this mode, MCAN does NOT provide any synchronization primitives that user can rely on in order to guarantee integrity of the data being received.

General guideline from the datasheet suggests that user should never read the oldest element in queue (as there is a risk that the message is currently being overwritten) and index should be offsetted by 1 or more (counting from the oldest message) depending on the speed of the CPU.

Thus, it is up to the application developer to provide such an index offset so read out messages are correct.