pub struct OwnedInterruptSet<Id, State = Dynamic>(/* private fields */);Expand description
Has exclusive access to a set of interrupts for Id CAN peripheral.
Permits safe access to the owned interrupt flags.
Implementations
Sourceimpl<Id: CanId, State> OwnedInterruptSet<Id, State>
impl<Id: CanId, State> OwnedInterruptSet<Id, State>
Sourcepub fn split(&mut self, subset: InterruptSet) -> Result<Self, MaskError>
pub fn split(&mut self, subset: InterruptSet) -> Result<Self, MaskError>
Moves ownership of the interrupts described by subset from self to
the return value. If self does not contain subset, an error is
returned.
Sourceimpl<Id: CanId, State: MaybeEnabled> OwnedInterruptSet<Id, State>
impl<Id: CanId, State: MaybeEnabled> OwnedInterruptSet<Id, State>
Sourcepub fn split_flagged(&mut self) -> Self
pub fn split_flagged(&mut self) -> Self
Moves ownership of the interrupts that were flagged to the return value.
Sourcepub fn iter_flagged(&self) -> Iter ⓘ
pub fn iter_flagged(&self) -> Iter ⓘ
Clears the flagged interrupts owned by this OwnedInterruptSet and
provides an iterator over the flags that were cleared.
Sourcepub fn interrupt_flags(&self) -> InterruptSet
pub fn interrupt_flags(&self) -> InterruptSet
Get the subset of interrupts in this set that are currently flagged.
Sourcepub fn clear_interrupts(&self, interrupts: InterruptSet)
pub fn clear_interrupts(&self, interrupts: InterruptSet)
Clear the indicated interrupts. Interrupts not owned by this
OwnedInterruptSet are silently ignored.